#!/bin/bash

exec &> >(tee -a /tmp/$(basename $0).log)

if $(which rpm &>/dev/null)
then
	yum -y install cups &> /dev/null
	CUPS_MAJOR_VER=`rpm -q cups --queryformat '%{version}' | awk -F\. '{print $1}'`
	CUPS_MINOR_VER=`rpm -q cups --queryformat '%{version}' | awk -F\. '{print $2}'`
	RPM_BASED=1
elif $(which dpkg &>/dev/null)
then
	apt-get install cups -y &> /dev/null
    CUPS_MAJOR_VER=`dpkg -s cups | grep Version | awk '{print $2}' | awk -F\. '{print $1}'`
    CUPS_MINOR_VER=`dpkg -s cups | grep Version | awk '{print $2}' | awk -F\. '{print $2}'`
	RPM_BASED=0
else
    echo "You use unknown Linux distro! Call Edward!"
fi

case $CUPS_MAJOR_VER in
	1)	case $CUPS_MINOR_VER in
			[0-5])	BROWSEPOLL_IS_DEFINED=`grep -ic ^browsepoll /etc/cups/cupsd.conf`
					if [ $BROWSEPOLL_IS_DEFINED -eq 1 ]
					then
						sed -i 's/BrowsePoll.*/BrowsePoll cbp-lprint01.weizmann.ac.il/' /etc/cups/cupsd.conf
					else
						echo "BrowsePoll cbp-lprint01.weizmann.ac.il" >> /etc/cups/cupsd.conf
					fi
			;;
			[6-99])	cp /etc/cups/cups-browsed.conf /etc/cups/cups-browsed.conf-orig
					echo "BrowseRemoteProtocols dnssd cups" > /etc/cups/cups-browsed.conf
					echo "BrowsePoll cbp-lprint01.weizmann.ac.il" >> /etc/cups/cups-browsed.conf
					if $(ps --pid 1 | grep systemd &>/dev/null)
					then
						cat <<-EOF > /etc/systemd/system/cups-browsed.service
						[Unit]
						Description=Make remote CUPS printers available locally
						Requires=cups.service
						After=cups.service
						
						[Service]
						ExecStart=/usr/sbin/cups-browsed
						
						[Install]
						WantedBy=multi-user.target
						EOF
						systemctl daemon-reload

						systemctl stop avahi-daemon avahi-daemon.socket
						systemctl disable avahi-daemon						
					    systemctl restart cups-browsed.service
						systemctl enable cups-browsed.service
					else
					    service cups-browsed restart
						service avahi-daemon stop
						if [ $RPM_BASED -eq 1 ]
						then
							chkconfig cups-browsed on
							chkconfig avahi-daemon off
						else
							update-rc.d cups-browsed enable
							update-rc.d avahi-daemon disable
						fi
					fi
			;;
		esac
	;;
	2)	cp /etc/cups/cups-browsed.conf /etc/cups/cups-browsed.conf-orig
        echo "BrowseRemoteProtocols dnssd cups\n" > /etc/cups/cups-browsed.conf
        echo "BrowsePoll cbp-lprint01.weizmann.ac.il" >> /etc/cups/cups-browsed.conf
		echo "LocalQueueNamingRemoteCUPS RemoteName" >> /etc/cups/cups-browsed.conf
		
		if $(ps --pid 1 | grep systemd &>/dev/null)
		then
			cat <<-EOF > /etc/systemd/system/cups-browsed.service
			[Unit]
			Description=Make remote CUPS printers available locally
			Requires=cups.service
			After=cups.service
			
			[Service]
			ExecStart=/usr/sbin/cups-browsed
			
			[Install]
			WantedBy=multi-user.target
			EOF
			systemctl daemon-reload
			
		    systemctl stop avahi-daemon avahi-daemon.socket
			systemctl disable avahi-daemon
			systemctl enable cups-browsed.service
			systemctl stop cups.service cups-browsed.service
			rm -rf /etc/cups/printers.conf /etc/cups/ppd/* /var/cache/cups/* /var/spool/cups/*
			systemctl start cups.service cups-browsed.service
			echo "Creating cron.daily entry..."
			
			cat <<-EOF >  /etc/cron.daily/refresh-cups-browsed
			systemctl stop cups.service cups-browsed.service
			rm -rf /etc/cups/printers.conf /etc/cups/ppd/* /var/cache/cups/* /var/spool/cups/*
			systemctl start cups.service cups-browsed.service
			EOF
			chmod 755 /etc/cron.daily/refresh-cups-browsed
		else
		    service cups-browsed stop
			service cups stop
			service avahi-daemon stop
			rm -rf /etc/cups/printers.conf /etc/cups/ppd/* /var/cache/cups/* /var/spool/cups/*
			service cups start
			service cups-browsed start
			echo "Creating cron.daily entry..."
			cat <<-EOF >  /etc/cron.daily/refresh-cups-browsed
			service cups-browsed stop
			service cups stop
			rm -rf /etc/cups/printers.conf /etc/cups/ppd/* /var/cache/cups/* /var/spool/cups/*
			service cups start
			service cups-browsed start
			EOF
			chmod 755 /etc/cron.daily/refresh-cups-browsed
			if [ $RPM_BASED -eq 1 ]
			then
				chkconfig cups-browsed on
				chkconfig avahi-daemon off
			else
				update-rc.d cups-browsed enable
				update-rc.d avahi-daemon disable
			fi
		fi
	;;
	*)	echo "You use strange CUPS version! Call Edward!"
	;;
esac

# Use printers on local CUPS server
echo "ServerName localhost" > /etc/cups/client.conf

if $(ps --pid 1 | grep systemd &>/dev/null)
then
	systemctl restart cups.service
else
	service cups restart
fi